==> AMR_0.7.1.tar.gz: AMR/R/globals.R <==
# ==================================================================== #
# TITLE                                                                #
# Antimicrobial Resistance (AMR) Analysis                              #
#                                                                      #
# SOURCE                                                               #
# https://gitlab.com/msberends/AMR                                     #
#                                                                      #
# LICENCE                                                              #
# (c) 2019 Berends MS (m.s.berends@umcg.nl), Luz CF (c.f.luz@umcg.nl)  #
#                                                                      #
# This R package is free software; you can freely use and distribute   #
# it for both personal and commercial purposes under the terms of the  #
# GNU General Public License version 2.0 (GNU GPL-2), as published by  #
# the Free Software Foundation.                                        #
#                                                                      #
# This R package was created for academic research and was publicly    #
# released in the hope that it will be useful, but it comes WITHOUT    #
# ANY WARRANTY OR LIABILITY.                                           #
# Visit our website for more info: https://msberends.gitlab.io/AMR.    #
# ==================================================================== #

globalVariables(c(".",
                  "..property",
                  "ab",
                  "abbreviations",
                  "mdr",
                  "mono_count",
                  "second",
                  "xdr",
                  "antibiotic",
                  "Antibiotic",
                  "antibiotics",
                  "atc",
                  "authors",
                  "Becker",
                  "CNS_CPS",
                  "cnt",
                  "col_id",
                  "count",
                  "count.x",
                  "count.y",
                  "cum_count",
                  "cum_percent",
                  "date_lab",
                  "diff.percent",
                  "fctlvl",
                  "First name",
                  "first_isolate_row_index",
                  "Freq",
                  "fullname",
                  "fullname_lower",
                  "genus",
                  "gramstain",
                  "index",
                  "input",
                  "Interpretation",
                  "interpretation",
                  "item",
                  "key_ab",
                  "key_ab_lag",
                  "key_ab_other",
                  "kingdom",
                  "labs",
                  "Lancefield",
                  "lang",
                  "Last name",
                  "lbl",
                  "lookup",
                  "median",
                  "mic",
                  "microorganisms",
                  "microorganisms.codes",
                  "microorganisms.old",
                  "microorganisms.oldDT",
                  "microorganisms.prevDT",
                  "microorganisms.unprevDT",
                  "microorganismsDT",
                  "mo",
                  "mo.old",
                  "more_than_episode_ago",
                  "MPM",
                  "n",
                  "name",
                  "new",
                  "observations",
                  "observed",
                  "official",
                  "old",
                  "other_pat_or_mo",
                  "package_v",
                  "Pasted",
                  "patient_id",
                  "pattern",
                  "phylum",
                  "plural",
                  "prevalence",
                  "prevalent",
                  "property",
                  "psae",
                  "R",
                  "real_first_isolate",
                  "ref",
                  "reference.rule",
                  "reference.rule_group",
                  "rsi",
                  "rule_group",
                  "rule_name",
                  "S",
                  "se_max",
                  "se_min",
                  "septic_patients",
                  "Sex",
                  "shortname",
                  "species",
                  "species_id",
                  "subspecies",
                  "synonyms",
                  "trade_name",
                  "trans",
                  "transmute",
                  "tsn",
                  "tsn_new",
                  "txt",
                  "value",
                  "Value",
                  "x",
                  "y",
                  "year"))

==> AMR_0.8.0.tar.gz: AMR/R/globals.R <==
# ==================================================================== #
# TITLE                                                                #
# Antimicrobial Resistance (AMR) Analysis                              #
#                                                                      #
# SOURCE                                                               #
# https://gitlab.com/msberends/AMR                                     #
#                                                                      #
# LICENCE                                                              #
# (c) 2019 Berends MS (m.s.berends@umcg.nl), Luz CF (c.f.luz@umcg.nl)  #
#                                                                      #
# This R package is free software; you can freely use and distribute   #
# it for both personal and commercial purposes under the terms of the  #
# GNU General Public License version 2.0 (GNU GPL-2), as published by  #
# the Free Software Foundation.                                        #
#                                                                      #
# This R package was created for academic research and was publicly    #
# released in the hope that it will be useful, but it comes WITHOUT    #
# ANY WARRANTY OR LIABILITY.                                           #
# Visit our website for more info: https://msberends.gitlab.io/AMR.    #
# ==================================================================== #

globalVariables(c(".",
                  "..property",
                  "ab",
                  "ab_txt",
                  "abbreviations",
                  "antibiotic",
                  "CNS_CPS",
                  "col_id",
                  "count",
                  "count.x",
                  "date_lab",
                  "diff.percent",
                  "First name",
                  "first_isolate_row_index",
                  "fullname",
                  "fullname_lower",
                  "genus",
                  "gramstain",
                  "group",
                  "index",
                  "input",
                  "interpretation",
                  "isolates",
                  "item",
                  "key_ab",
                  "key_ab_lag",
                  "key_ab_other",
                  "kingdom",
                  "kingdom_index",
                  "lang",
                  "Last name",
                  "lookup",
                  "mdr",
                  "median",
                  "microorganisms",
                  "microorganisms.codes",
                  "missing_names",
                  "mo",
                  "mono_count",
                  "more_than_episode_ago",
                  "name",
                  "new",
                  "newvar_date",
                  "newvar_genus_species",
                  "newvar_mo",
                  "newvar_patient_id",
                  "newvar_row_index",
                  "newvar_row_index_sorted",
                  "observations",
                  "observed",
                  "old",
                  "old_name",
                  "other_pat_or_mo",
                  "package_version",
                  "patient_id",
                  "pattern",
                  "plural",
                  "prevalence",
                  "R",
                  "real_first_isolate",
                  "ref",
                  "rule_group",
                  "rule_name",
                  "S",
                  "se_max",
                  "se_min",
                  "second",
                  "Sex",
                  "species",
                  "species_id",
                  "subspecies",
                  "synonyms",
                  "total",
                  "txt",
                  "uncertainty_level",
                  "value",
                  "x",
                  "xdr",
                  "y",
                  "year"))
